@@ -1,7 +1,8 @@
 /*
  * libxlsxwriter
  *
- * Copyright 2014-2022, John McNamara, jmcnamara@cpan.org. See LICENSE.txt.
+ * SPDX-License-Identifier: BSD-2-Clause
+ * Copyright 2014-2024, John McNamara, jmcnamara@cpan.org.
  */
 
 /**
@@ -182,34 +183,34 @@ typedef struct lxw_defined_name {
  */
 typedef struct lxw_doc_properties {
     /** The title of the Excel Document. */
-    char *title;
+    const char *title;
 
     /** The subject of the Excel Document. */
-    char *subject;
+    const char *subject;
 
     /** The author of the Excel Document. */
-    char *author;
+    const char *author;
 
     /** The manager field of the Excel Document. */
-    char *manager;
+    const char *manager;
 
     /** The company field of the Excel Document. */
-    char *company;
+    const char *company;
 
     /** The category of the Excel Document. */
-    char *category;
+    const char *category;
 
     /** The keywords of the Excel Document. */
-    char *keywords;
+    const char *keywords;
 
     /** The comment field of the Excel Document. */
-    char *comments;
+    const char *comments;
 
     /** The status of the Excel Document. */
-    char *status;
+    const char *status;
 
     /** The hyperlink base URL of the Excel Document. */
-    char *hyperlink_base;
+    const char *hyperlink_base;
 
     /** The file creation date/time shown in Excel. This defaults to the
      * current time and date if set to 0. If you wish to create files that are
@@ -270,13 +271,13 @@ typedef struct lxw_workbook_options {
     uint8_t constant_memory;
 
     /** Directory to use for the temporary files created by libxlsxwriter. */
-    char *tmpdir;
+    const char *tmpdir;
 
     /** Allow ZIP64 extensions when creating the xlsx file zip container. */
     uint8_t use_zip64;
 
     /** Output buffer to use instead of writing to a file */
-    char **output_buffer;
+    const char **output_buffer;
 
     /** Used with output_buffer to get the size of the created buffer */
     size_t *output_buffer_size;
@@ -341,6 +342,7 @@ typedef struct lxw_workbook {
     lxw_hash_table *used_dxf_formats;
 
     char *vba_project;
+    char *vba_project_signature;
     char *vba_codename;
 
     lxw_format *default_url_format;
@@ -966,7 +968,7 @@ lxw_error workbook_validate_sheet_name(lxw_workbook *workbook,
  *     workbook_add_vba_project(workbook, "vbaProject.bin");
  * @endcode
  *
- * Only one `vbaProject.bin file` can be added per workbook. The name doesn't
+ * Only one `vbaProject.bin` file can be added per workbook. The name doesn't
  * have to be `vbaProject.bin`. Any suitable path/name for an existing VBA bin
  * file will do.
  *
@@ -985,6 +987,35 @@ lxw_error workbook_validate_sheet_name(lxw_workbook *workbook,
 lxw_error workbook_add_vba_project(lxw_workbook *workbook,
                                    const char *filename);
 
+/**
+ * @brief Add a vbaProject binary and a vbaProjectSignature binary to the Excel
+ * workbook.
+ *
+ * @param workbook    Pointer to a lxw_workbook instance.
+ * @param vba_project The path/filename of the vbaProject.bin file.
+ * @param signature   The path/filename of the vbaProjectSignature.bin file.
+ *
+ * The `%workbook_add_signed_vba_project()` function can be used to add digitally
+ * signed macros or functions to a workbook. The function adds a binary VBA project
+ * file and a binary VBA project signature file that have been extracted from an
+ * existing Excel xlsm file with digitally signed macros:
+ *
+ * @code
+ *     workbook_add_signed_vba_project(workbook, "vbaProject.bin", "vbaProjectSignature.bin");
+ * @endcode
+ *
+ * Only one `vbaProject.bin` file can be added per workbook. The name doesn't
+ * have to be `vbaProject.bin`. Any suitable path/name for an existing VBA bin
+ * file will do. The same applies for `vbaProjectSignature.bin`.
+ *
+ * See also @ref working_with_macros
+ *
+ * @return A #lxw_error.
+ */
+lxw_error workbook_add_signed_vba_project(lxw_workbook *workbook,
+                                          const char *vba_project,
+                                          const char *signature);
+
 /**
  * @brief Set the VBA name for the workbook.
  *
