@@ -3,7 +3,8 @@
  *
  * Used in conjunction with the libxlsxwriter library.
  *
- * Copyright 2014-2022, John McNamara, jmcnamara@cpan.org. See LICENSE.txt.
+ * SPDX-License-Identifier: BSD-2-Clause
+ * Copyright 2014-2024, John McNamara, jmcnamara@cpan.org.
  *
  */
 
@@ -98,6 +99,8 @@ lxw_format_new(void)
     format->color_indexed = LXW_FALSE;
     format->font_only = LXW_FALSE;
 
+    format->quote_prefix = LXW_FALSE;
+
     return format;
 
 mem_error:
@@ -799,3 +802,12 @@ format_set_hyperlink(lxw_format *self)
     self->underline = LXW_UNDERLINE_SINGLE;
     self->theme = 10;
 }
+
+/*
+ * Set the quote_prefix property.
+ */
+void
+format_set_quote_prefix(lxw_format *self)
+{
+    self->quote_prefix = LXW_TRUE;
+}
