@@ -3,7 +3,8 @@
  *
  * Test to compare output against Excel files.
  *
- * Copyright 2014-2022, John McNamara, jmcnamara@cpan.org
+ * SPDX-License-Identifier: BSD-2-Clause
+ * Copyright 2014-2024, John McNamara, jmcnamara@cpan.org.
  *
  */
 
@@ -108,7 +109,7 @@ int main() {
     worksheet_autofilter(worksheet, 0, 0, 50, 3);
 
 
-    char* list[] = {"3000", "5000", "8000", NULL};
+    const char* list[] = {"3000", "5000", "8000", NULL};
 
     worksheet_filter_list(worksheet, 2, list);
 
