@@ -3,7 +3,8 @@
  *
  * Test to compare output against Excel files.
  *
- * Copyright 2014-2022, John McNamara, jmcnamara@cpan.org
+ * SPDX-License-Identifier: BSD-2-Clause
+ * Copyright 2014-2024, John McNamara, jmcnamara@cpan.org.
  *
  */
 
@@ -21,7 +22,7 @@ int main() {
 
     (void)worksheet;
 
-    free(properties->hyperlink_base);
+    free((void *)properties->hyperlink_base);
     free(properties);
 
     return workbook_close(workbook);
