@@ -2,7 +2,8 @@
 #
 # Tests for libxlsxwriter.
 #
-# Copyright 2014-2022, John McNamara, jmcnamara@cpan.org
+# SPDX-License-Identifier: BSD-2-Clause
+# Copyright 2014-2024, John McNamara, jmcnamara@cpan.org.
 #
 
 import base_test_class
@@ -104,3 +105,9 @@ class TestCompareXLSXFiles(base_test_class.XLSXBaseTest):
 
     def test_table26(self):
         self.run_exe_test('test_table26')
+
+    def test_table29(self):
+        self.run_exe_test('test_table29')
+
+    def test_table30(self):
+        self.run_exe_test('test_table30')
